@@ -6,8 +6,11 @@ import requests
 from dacite import from_dict, MissingValueError
 
 from wyylde_sdk.models import (
+    ContactUserResource,
+    CrushResource,
     EventResource,
     TalkResource,
+    TalkCounterResource,
     TestimonyResource,
     UserResource,
     VisitResource,
@@ -69,8 +72,23 @@ class Session(requests.Session):
         params.update(extra)
         return params
 
+    def get_count(self, endpoint: str, params: Optional[dict[str, Any]] = None, data_path: Optional[str] = None):
+        params = params or {}
+        params = self.make_params(**params)
+        response = self.get(
+            f'https://www.wyylde.com/rest/{endpoint}',
+            params=params
+        ).json()
+        if data_path is None:
+            for k in response['data']:
+                if k.startswith('nb_'):
+                    data_path = k
+                    break
+        return response['data'][data_path]
+
     def get_generate(
-        self, endpoint: str, klass: Type[T], params: Optional[dict[str, Any]]=None
+        self, endpoint: str, klass: Type[T], params: Optional[dict[str, Any]] = None,
+        data_path: Optional[str] = None,
     ) -> Iterable[T]:
         '''
         Generator function that yields elements of an array as their corresponding models.
@@ -92,7 +110,7 @@ class Session(requests.Session):
             f'https://www.wyylde.com/rest/{endpoint}',
             params=params
         ).json()
-        data_path = endpoint.split('/').pop()
+        data_path = endpoint.split('/').pop() if data_path is None else data_path
         while response is not None:
             next_id: str = response['data']['next']
             for item in response['data'][data_path]:
@@ -104,7 +122,7 @@ class Session(requests.Session):
                         file=sys.stderr
                     )
                     continue
-            if next_id is not None:
+            if next_id is None:
                 break
             response = self.get(
                 f'https://www.wyylde.com/rest/{endpoint}/{next_id}',
@@ -122,6 +140,14 @@ class WyyldeClient:
         params = {'nb': '20'}
         return self.session.get_generate('talks', TalkResource, params=params)
 
+    @property
+    def total_talks(self) -> TalkCounterResource:
+        params = {'nb': '20'}
+        return from_dict(
+            TalkCounterResource,
+            self.session.get_count('talks', params=params, data_path='counters')
+        )
+
     def delete_talk(self, talk_id: str):
         self.session.delete(
             f'https://www.wyylde.com/rest/talks/{talk_id}',
@@ -135,11 +161,28 @@ class WyyldeClient:
             json={'msg': message}
         )
 
-    def get_testimonies(self, user_id: str) -> Iterable[TestimonyResource]:
+    def testimonies(self, user_id: str) -> Iterable[TestimonyResource]:
         return self.session.get_generate(
             f'profile/{user_id}/testimonies', TestimonyResource
         )
 
+    def total_testimonies(self, user_id: str) -> int:
+        return self.session.get_count(
+            f'profile/{user_id}/testimonies', data_path='nb_users'
+        )
+
+    @property
+    def contacts(self):
+        return self.session.get_generate(
+            'my/contacts', ContactUserResource, data_path='users'
+        )
+
+    @property
+    def total_contacts(self):
+        return self.session.get_count(
+            'my/contacts', data_path='nb_users'
+        )
+
     @property
     def events(self) -> Iterable[EventResource]:
         params = {
@@ -173,3 +216,12 @@ class WyyldeClient:
         return self.session.get_generate(
             'my/visits', VisitResource, params=params
         )
+
+    @property
+    def crushes(self) -> Iterable[CrushResource]:
+        params = {
+            'version': self.session.wyylde_version,
+        }
+        return self.session.get_generate(
+            'my/crush', CrushResource, params=params, data_path='crushes'
+        )
